/* Copyright (C) 1994  R.M.King
This file is part of the Linux C Library.

The Linux C Library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public License as
published by the Free Software Foundation; either version 2 of the
License, or (at your option) any later version.

The Linux C Library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.  */

#ifndef _ARM_FPU_CONTROL_H
#define _ARM_FPU_CONTROL_H

/*
 *  31-24 23-21 20  19  18  17  16  15-13 12  11  10   9   8   7- 5  4   3   2   1   0
 * |  S  |     | I | U | O | D | I |     | A | E | S | N | N |     | I | U | O | D | I |
 * |  I  |  0  | N | F | F | V | V |  0  | C | P | O | E | D |  0  | N | F | F | V | V |
 * |  D  |     | X | L | L | Z | O |     |   |   |   |   |   |     | X | L | L | Z | O |
 *       |       Trap Enable       |       Sys Control       |     Cum. Excptn Flags   |
 */

#include <features.h>
 
/* Trap enable flags */
#define _FPU_TE_INX	(1<<20)	/* Inexact */
#define _FPU_TE_UFL	(1<<19)	/* Underflow */
#define _FPU_TE_OFL	(1<<18)	/* Overflow */
#define _FPU_TE_DVZ	(1<<17)	/* Divide by zero */
#define _FPU_TE_IVO	(1<<16)	/* Invalid operation */

/* System control flags */
#define _FPU_SC_AC	(1<<12)	/* Alternate definition of C-flag */
#define _FPU_SC_EP	(1<<11)	/* Expanded-packed decimal format */
#define _FPU_SC_SO	(1<<10)	/* Synchronous operation */
#define _FPU_SC_NE	(1<<9)	/* NaN Exception */
#define _FPU_SC_ND	(1<<8)	/* No denormalised numbers */

/* Exception flags */
#define _FPU_EF_INX	(1<<4)	/* Inexact */
#define _FPU_EF_UFL	(1<<3)	/* Underflow */
#define _FPU_EF_OFL	(1<<2)	/* Overflow */
#define _FPU_EF_DVZ	(1<<1)	/* Divide by zero */
#define _FPU_EF_IVO	(1<<0)	/* Invalid operation */

#define _FPU_RESERVED	0xFFE0E0E0

/* Now two recommeded words */

/* Linux default:
	- exceptions on overflow, zero divide, invalid operation and NaN */
#define _FPU_DEFAULT	(_FPU_TE_UFL|            _FPU_TE_DVZ|_FPU_TE_IVO|_FPU_SC_NE)

/* IEEE: same as above, but with all exceptions */
#define _FPU_IEEE	(_FPU_TE_UFL|_FPU_TE_OFL|_FPU_TE_DVZ|_FPU_TE_IVO|_FPU_SC_NE)

/* private namespace. It should only be used by crt0.o. */
extern unsigned short __fpu_control;

__BEGIN_DECLS

/* called by crt0.o. It can be used to manipulate 387 control word. */
extern void __setfpucw __P ((unsigned short));

__END_DECLS

#endif	/* _ARM_FPU_CONTROL */
